@@ -1,18 +1,13 @@
-# Copyright (c) 2016, 2018, 2020 Claudiu Popa <pcmanticore@gmail.com>
-# Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
-# Copyright (c) 2020-2021 hippo91 <guillaume.peillex@gmail.com>
-# Copyright (c) 2020 David Gilman <davidgilman1@gmail.com>
-# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
-
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/master/LICENSE
+# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
 
 from astroid.bases import BoundMethod
 from astroid.brain.helpers import register_module_extender
 from astroid.builder import parse
 from astroid.exceptions import InferenceError
 from astroid.manager import AstroidManager
-from astroid.scoped_nodes import FunctionDef
+from astroid.nodes.scoped_nodes import FunctionDef
 
 
 def _multiprocessing_transform():
@@ -83,6 +78,7 @@ def _multiprocessing_managers_transform():
         Queue = JoinableQueue = queue.Queue
         Event = threading.Event
         RLock = threading.RLock
+        Lock = threading.Lock
         BoundedSemaphore = threading.BoundedSemaphore
         Condition = threading.Condition
         Barrier = threading.Barrier
