@@ -2,8 +2,7 @@
 # For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
 # Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
 
-"""This module contains some mixins for the different nodes.
-"""
+"""This module contains some mixins for the different nodes."""
 
 import warnings
 
@@ -28,4 +27,5 @@ __all__ = (
 warnings.warn(
     "The 'astroid.mixins' module is deprecated and will become private in astroid 3.0.0",
     DeprecationWarning,
+    stacklevel=2,
 )
