@@ -1,3 +1,7 @@
+# Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
+# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
+
 # pylint: disable=unused-import
 
 import warnings
@@ -24,6 +28,8 @@ from astroid.nodes.scoped_nodes import (
 # Please remove astroid/scoped_nodes.py|astroid/node_classes.py in autoflake
 # exclude when removing this file.
 warnings.warn(
-    "The 'astroid.scoped_nodes' module is deprecated and will be replaced by 'astroid.nodes' in astroid 3.0.0",
+    "The 'astroid.scoped_nodes' module is deprecated and will be replaced by "
+    "'astroid.nodes' in astroid 3.0.0",
     DeprecationWarning,
+    stacklevel=2,
 )
